@@ -1241,23 +1241,31 @@ gboolean cb_keyPressed (GtkWidget *, GdkEventKey * e, Application *app) {
                 CONTROL(app)->process ()->volume (-2, false);
             break;
         case GDK_Left:
-            if (CONTROL(app)->process ()->playing ())
+            if (gtk_window_get_focus (app->window) == app->playlist_view)
+                collapseSelectedList (app);
+            else if (CONTROL(app)->process ()->playing ())
                 CONTROL(app)->process ()->seek (-200, false); // 20s
             break;
         case GDK_Right:
-            if (CONTROL(app)->process ()->playing ())
+            if (gtk_window_get_focus (app->window) == app->playlist_view)
+                expandSelectedList (app);
+            else if (CONTROL(app)->process ()->playing ())
                 CONTROL(app)->process ()->seek (200, false); // 20s
             break;
+        case GDK_KP_Enter:
         case GDK_Return: // HILDON_HARDKEY_SELECT
-            if (testFullscreenPlaylist (app))
+            if (gtk_window_get_focus (app->window) == app->playlist_view ||
+                    testFullscreenPlaylist (app))
                 rowSelected (app);
             break;
         case GDK_Up:
-            if (testFullscreenPlaylist (app))
+            if (gtk_window_get_focus (app->window) == app->playlist_view ||
+                    testFullscreenPlaylist (app))
                 previousSelected (app);
             break;
         case GDK_Down:
-            if (testFullscreenPlaylist (app))
+            if (gtk_window_get_focus (app->window) == app->playlist_view ||
+                    testFullscreenPlaylist (app))
                 nextSelected (app);
             break;
         case GDK_Escape:
