@@ -250,12 +250,11 @@ void KMPlayer::updatePlayTree (Application *app) {
 void KMPlayer::updateTree (Application * app, short id) {
     GtkTreeView *treeview = GTK_TREE_VIEW (app->playlist_view);
     GtkTreeIter valid_iter, *iter;
-    GtkTreePath * fpath = 0L, * rpath;
+    GtkTreePath *fpath = 0L;
     GtkTreeIter oldriter, riter;
     bool valid_tree = false;
     PlayListData *pld = CONTROL(app)->playlist_data;
     GtkTreeModel *model = gtk_tree_view_get_model (treeview);
-    GtkTreeSelection *sel = gtk_tree_view_get_selection (treeview);
     Document *doc;
 
     for (valid_tree = gtk_tree_model_get_iter_first (model, &oldriter );
@@ -294,13 +293,8 @@ void KMPlayer::updateTree (Application * app, short id) {
             gtk_tree_store_insert_before(GTK_TREE_STORE(model),&riter,0L,&oldriter);
         else
             gtk_tree_store_append (GTK_TREE_STORE(model), &riter, 0L);
-        rpath = gtk_tree_model_get_path (model, &riter);
         populate (GTK_TREE_STORE (model), pld,
                 pld->document.ptr (), &riter, 0L, &fpath);
-        if (!fpath)
-            fpath = rpath;
-        else
-            gtk_tree_path_free (rpath);
 
         while (!gtk_tree_model_get_iter (model, &valid_iter, fpath) &&
                 gtk_tree_path_up (fpath));
@@ -313,8 +307,6 @@ void KMPlayer::updateTree (Application * app, short id) {
         gtk_tree_view_set_cursor (treeview, fpath, NULL, false);
         gtk_tree_view_scroll_to_cell (treeview, fpath, NULL, false, 0, 0);
         gtk_tree_path_free (fpath);
-    } else {
-        gtk_tree_selection_unselect_all (sel);
     }
 
     pld->updated_document = doc;
@@ -358,8 +350,40 @@ static PlayListData * getListDataFromSelection (Application * app, GtkTreePath *
     return 0L;
 }
 
-void cb_treecel_edited (GtkCellRendererText *cell, gchar *arg1, gchar *arg2, gpointer data) {
-    //g_print ("cb_treecel_edited %s %s\n", arg1, arg2);
+void collapseSelectedList (Application *app)
+{
+    GtkTreeIter iter;
+    GtkTreeView *tree = GTK_TREE_VIEW (app->playlist_view);
+    GtkTreeSelection *sel = gtk_tree_view_get_selection (tree);
+    if (gtk_tree_selection_get_selected (sel, 0L, &iter)) {
+        GtkTreeModel *model = gtk_tree_view_get_model (tree);
+        GtkTreePath *path = gtk_tree_model_get_path (model, &iter);
+        if (gtk_tree_model_iter_n_children (model, &iter) &&
+                gtk_tree_view_row_expanded (tree, path)) {
+            gtk_tree_view_collapse_row (tree, path);
+        } else if (gtk_tree_path_get_depth (path) > 1) {
+            gtk_tree_path_up (path);
+            gtk_tree_view_collapse_row (tree, path);
+        }
+        gtk_tree_view_set_cursor (tree, path, NULL, false);
+        gtk_tree_path_free (path);
+    }
+}
+
+void expandSelectedList (Application *app)
+{
+    GtkTreeIter iter;
+    GtkTreeView *tree = GTK_TREE_VIEW (app->playlist_view);
+    GtkTreeSelection *sel = gtk_tree_view_get_selection (tree);
+    if (gtk_tree_selection_get_selected (sel, 0L, &iter)) {
+        GtkTreeModel *model = gtk_tree_view_get_model (tree);
+        GtkTreePath *path = gtk_tree_model_get_path (model, &iter);
+        if (gtk_tree_model_iter_n_children (model, &iter) &&
+                !gtk_tree_view_row_expanded (tree, path)) {
+            gtk_tree_view_expand_row (tree, path, FALSE);
+        }
+        gtk_tree_path_free (path);
+    }
 }
 
 void cb_treerow_expanded (GtkTreeView *treeview, GtkTreeIter *arg1, GtkTreePath *arg2, gpointer user_data) {
@@ -768,8 +792,6 @@ GtkWidget * createTreeView (Application * app) {
     g_object_set (G_OBJECT (view), "headers-visible", FALSE, 0L);
     g_object_set (G_OBJECT (app->playlist_cell_renderer),
             "font", "Sans 15", 0L);
-    g_signal_connect (G_OBJECT (app->playlist_cell_renderer),
-            "edited", G_CALLBACK (cb_treecel_edited), app);
     gtk_tree_view_column_pack_start(col, app->playlist_cell_renderer, TRUE);
     gtk_tree_view_column_set_attributes(col, app->playlist_cell_renderer,
             "text", COL_TEXT,
