@@ -428,7 +428,7 @@ KMPLAYER_NO_EXPORT bool MPlayer::play (NodePtr node) {
     request_quit = false;
     outbuf[0] = 0;
     String cmdline (path);
-    cmdline += " -nofs -slave -framedrop -identify -vo ";
+    cmdline += " -nofs -slave -identify -vo ";
     char buf[128];
     //if (has_xv)
     //    snprintf (buf, sizeof(buf), "xv -wid %u ", m_viewer);
@@ -627,11 +627,11 @@ KMPLAYER_NO_EXPORT void MPlayer::writeEvent (UnixProcess *) {
 
 KMPLAYER_NO_EXPORT void MPlayer::readEvent (UnixProcess *) {
     int inbuf = strlen (outbuf);
-    gsize nr = unix_process.readStdOut (outbuf + inbuf, sizeof (outbuf) -inbuf);
+    inbuf += unix_process.readStdOut (outbuf + inbuf, sizeof (outbuf) -inbuf-1);
     //debugLog() << "read " << nr << " chars had " << inbuf << endl;
-    outbuf[inbuf + nr] = 0;
+    outbuf[inbuf] = 0;
     char *tok = outbuf;
-    for (int i = 0; i < inbuf + nr; i++) {
+    for (int i = 0; i < inbuf; i++) {
         if (outbuf[i] == '\r' && outbuf[i+1] != '\n') {
             outbuf[i] = 0;
             char * c = strstr (tok, "A:");
@@ -743,9 +743,13 @@ KMPLAYER_NO_EXPORT void MPlayer::readEvent (UnixProcess *) {
             tok = outbuf + i + 1;
         }
     }
-    inbuf = tok - outbuf;
-    if (inbuf > 0)
-        memmove (outbuf, tok, inbuf);
+    if (tok == outbuf && inbuf == sizeof (outbuf) - 1) {
+        inbuf = 0; //skip this line
+    } else {
+        inbuf -= tok - outbuf;
+        if (inbuf > 0)
+            memmove (outbuf, tok, inbuf);
+    }
     outbuf[inbuf] = 0;
 }
 
